@@ -8,10 +8,15 @@ SV * GetSignalEvent(Etk_Object * object, void * value, Callback_Signal_Data * cb
    HV *event_hv;
    SV *event_rv;
    
-   if(!strcmp(cbd->signal_name, "mouse_up") || !strcmp(cbd->signal_name, "mouse_down"))
+   if(!strcmp(cbd->signal_name, "mouse_up"))
      {	
-        Etk_Event_Mouse_Up_Down *event = value;   
-	event_rv = newSVEventMouseUpDown(event);
+        Etk_Event_Mouse_Up *event = value;   
+	event_rv = newSVEventMouseUp(event);
+     }
+   else if(!strcmp(cbd->signal_name, "mouse_down"))
+     {	
+        Etk_Event_Mouse_Down *event = value;   
+	event_rv = newSVEventMouseDown(event);
      }
    else if(!strcmp(cbd->signal_name, "mouse_move"))
      {
@@ -26,13 +31,17 @@ SV * GetSignalEvent(Etk_Object * object, void * value, Callback_Signal_Data * cb
 		   !strcmp(cbd->signal_name, "cell_value_changed")
 		   )
      {
-	event_rv = newSVEtkTreeRowPtr((Etk_Tree_Row *)value);
+	event_rv = newSVObj(value, getClass("Etk_Tree_Row"));
      }
-   else if(!strcmp(cbd->signal_name, "key_down") || !strcmp(cbd->signal_name, "key_up"))
+   else if(!strcmp(cbd->signal_name, "key_down"))
      {
-	Etk_Event_Key_Up_Down *key_event = value;
-	event_rv = newSVEventKeyUpDown(key_event);
-
+	Etk_Event_Key_Down *key_event = value;
+	event_rv = newSVEventKeyDown(key_event);
+     }
+   else if(!strcmp(cbd->signal_name, "key_up"))
+     {
+	Etk_Event_Key_Up *key_event = value;
+	event_rv = newSVEventKeyUp(key_event);
      }
    else
      {
